@@ -38,6 +38,7 @@ COUNTRIES = {
     "az": "Azerbaijan",
     "au": "Australia",
     "be": "Belgium",
+    "br": "Brazil",
     "ch": "Switzerland",
     "cz": "Czech Republic",
     "de": "Germany",
@@ -49,6 +50,7 @@ COUNTRIES = {
     "hk": "Hong Kong",
     "hr": "Croatia",
     "hu": "Hungary",
+    "ie": "Ireland",
     "il": "Israel",
     "ir": "Iran, Islamic Republic of",
     "is": "Iceland",
@@ -86,6 +88,7 @@ COUNTRIES_DVB_T = (
     "hk",
     "hr",
     "hu",
+    "ie",
     "il",
     "ir",
     "is",
@@ -109,6 +112,7 @@ COUNTRIES_DVB_T = (
 COUNTRIES_DVB_C = (
     "at",
     "be",
+    "br",
     "ch",
     "cz",
     "de",
